# Luparnet
    **Luparnet** is a barebones machine learning that creates a simple class "net". This
network can then be trained.




## Methods
	The network takes only two arguments in the constructor, the first being
the desired number of layers and the second being an array of the data dimensions.
The train function takes three arguments with an option for overload. The function
takes first the number of epochs to train for, the second is the input data, the
third is the output data. The final argument is an integer which allows for debugging
and user training.






